@@ -133,28 +133,12 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
     @pyqtSignature('QModelIndex')
     def on_exercises_list_view_clicked(self, index):
-        filename = self.model.record(index.row()).value('ex_media').toString()
-        ex_name = self.model.record(index.row()).value('ex_name').toString()
-        t_name = self.model.record(index.row()).value('t_name').toString()
-        f_name = self.model.record(index.row()).value('f_name').toString()
-        d_name = self.model.record(index.row()).value('d_name').toString()
-        i_name = self.model.record(index.row()).value('i_name').toString()
-        e_name = self.model.record(index.row()).value('e_name').toString()
-
-        print e_name
-
-        title = "%s (%s)" %(ex_name, t_name)
-
-        view_exercise_window = vew.ViewExerciseWindow(filename, self, self.db)
-        view_exercise_window.setWindowTitle(title)
-        view_exercise_window.frequency_value_button.setValueText(f_name)
-        view_exercise_window.duration_value_button.setValueText(d_name)
-        view_exercise_window.intensity_value_button.setValueText(i_name)
-        view_exercise_window.equipment_value_button.setValueText(e_name)
+        index = self.exercises_list_view.currentIndex()
 
+        view_exercise_window = vew.ViewExerciseWindow(self.model, index, 
+                                                      self.db, self)
         view_exercise_window.show()
 
-
     def exitFullScreen(self):
         self.exercises_list_view.clearSelection()
         self.exercises_list_view.setSelectionMode(QAbstractItemView.SingleSelection)
@@ -173,7 +157,9 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
         if action == edit_action:
             index = self.exercises_list_view.currentIndex()
             name = self.model.record(index.row()).value('ex_name')
+            print name.toString()
 
+            """
             exercise_wizard = ew.ExerciseWizard(self, self.db, name)
             exercise_wizard.exercisesUpdated.connect(self.refreshModel)
             exercise_wizard.setStartId(1)
@@ -195,9 +181,10 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
 
             e_name = self.model.record(index.row()).value('e_name')
             e_id = self.db.getRow('e_name', e_name)
+
+            ex_media = self.model.record(index.row()).value('ex_media')
             
 
-            media = self.model.index(index.row(),8).data()
             exercise_wizard.name_line_edit.setText(name.toString())
             exercise_wizard.description_text_edit.setHtml(description.toString())
             exercise_wizard.target_area_selector.setCurrentIndex(t_id)
@@ -205,10 +192,10 @@ class ExercisesWindow(QMainWindow, Ui_ExercisesWindow):
             exercise_wizard.duration_selector.setCurrentIndex(d_id)
             exercise_wizard.intensity_selector.setCurrentIndex(i_id)
             exercise_wizard.equipment_selector.setCurrentIndex(e_id)
-            exercise_wizard.media_line_edit.setText(media.toString())
+            exercise_wizard.media_line_edit.setText(ex_media.toString())
 
             exercise_wizard.show()
-
+            """
 
         elif action == delete_action:
             self.model.removeRow(self.exercises_list_view.currentIndex().row())
