@@ -60,9 +60,9 @@ class SettingsDialog(QDialog, Ui_SettingsDialog):
 
     def setupRememberLastFitnessCheckbox(self):
         if self.config.interface['remember-last-fitness']:
-            self.remember_last_fitness_checkbox.setCheckState(Qt.Checked)
+            self.remembes_last_fitness_checkbox.setCheckState(Qt.Checked)
         else:
-            self.remember_last_fitness_checkbox.setCheckState(Qt.Unchecked)
+            self.remembes_last_fitness_checkbox.setCheckState(Qt.Unchecked)
             self.config.interface['last-fitness'] = 'exercises'
 
     def on_button_box_accepted(self):
@@ -71,7 +71,7 @@ class SettingsDialog(QDialog, Ui_SettingsDialog):
         self.close()
 
     @pyqtSignature("int")
-    def on_remember_last_fitness_checkbox_stateChanged(self, state):
+    def on_remembes_last_fitness_checkbox_stateChanged(self, state):
         if state:
             self.config.interface['remember-last-fitness'] = 'Yes'
         else:
