@@ -30,7 +30,7 @@ import config as c
 
 # program modules 
 from ui.ui_target_areas_window import Ui_TargetAreasWindow
-import routines_window as ww
+import sessions_window as ww
 import exercises_window as ew
 
 class TargetAreasWindow(QMainWindow, Ui_TargetAreasWindow):
@@ -70,11 +70,11 @@ class TargetAreasWindow(QMainWindow, Ui_TargetAreasWindow):
         filtered_exercises_window.show()
 
     @pyqtSignature("bool")
-    def on_routines_action_triggered(self, checked):
-        self.config.interface['last-fitness'] = 'routines'
+    def on_sessions_action_triggered(self, checked):
+        self.config.interface['last-fitness'] = 'sessions'
         self.parent().setFitnessWindow()
-        routines_window = ww.RoutinesWindow(self.parent(), self.db)
-        routines_window.show()
+        sessions_window = ww.SessionsWindow(self.parent(), self.db)
+        sessions_window.show()
         self.hide()
 
 
